toolutil

package
v0.14.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	GOOSLinux   = "linux"
	GOOSWindows = "windows"
	GOOSDarwin  = "darwin"

	GOOSFreebsd   = "freebsd"
	GOOSOpenbsd   = "openbsd"
	GOOSNetbsd    = "netbsd"
	GOOSDragonfly = "dragonfly"
)
const MaxFileReadBytes = maxToolBytes

MaxFileReadBytes caps raw bytes read from disk by “read file” style tools.

const MaxFileWriteBytes = maxToolBytes

MaxFileWriteBytes caps raw bytes written to disk by “write file” style tools.

const MaxTextProcessingBytes = maxToolBytes

MaxTextProcessingBytes caps loading/editing text files for line-based tools.

Variables

This section is empty.

Functions

func CloneTool

func CloneTool(t spec.Tool) spec.Tool

func WithRecoveryResp added in v0.5.1

func WithRecoveryResp[T any](fn func() (T, error)) (result T, err error)

Types

This section is empty.

Jump to