Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DecodeJSONRaw ¶
func DecodeJSONRaw[T any](raw json.RawMessage) (T, error)
DecodeJSONRaw decodes a json.RawMessage into a typed value T, disallowing unknown fields and rejecting trailing data. If raw is empty, or only whitespace, it returns the zero value of T.
func EncodeToJSONRaw ¶
func EncodeToJSONRaw(value any) (json.RawMessage, error)
EncodeToJSONRaw encodes any value to json.RawMessage. No typed method here as value being of a type doesnt really affect its functionality.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.