Documentation
¶
Index ¶
Constants ¶
const ( GOOSLinux = "linux" GOOSWindows = "windows" GOOSDarwin = "darwin" GOOSFreebsd = "freebsd" GOOSOpenbsd = "openbsd" GOOSNetbsd = "netbsd" GOOSDragonfly = "dragonfly" )
const MaxFileReadBytes = maxToolBytes
MaxFileReadBytes caps raw bytes read from disk by “read file” style tools.
const MaxFileWriteBytes = maxToolBytes
MaxFileWriteBytes caps raw bytes written to disk by “write file” style tools.
const MaxTextProcessingBytes = maxToolBytes
MaxTextProcessingBytes caps loading/editing text files for line-based tools.
Variables ¶
This section is empty.
Functions ¶
func WithRecoveryResp ¶ added in v0.5.1
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.